==> buildlib-2.0.5-py3-none-any.whl: buildlib/wheel/lib.py <==
from typing import Optional
import shutil
import os
import glob
from cmdi import CmdResult, command, set_result, strip_args
import subprocess as sp
from buildlib import semver


def extract_version_from_wheel_name(name: str) -> str:
    """
    Get the version part out of the wheel file name.
    """
    parted: list = name.split('-')
    return '' if len(parted) < 2 else parted[1]


def find_wheel(
    wheel_dir: str,
    semver_num: Optional[str] = None,
    wheelver_num: Optional[str] = None,
    raise_not_found: Optional[bool] = False,
) -> Optional[str]:
    """
    Search dir for a wheel-file which contains a specific version number in its
    name. Return found wheel name or False.
    """

    if wheelver_num:
        requested_version: str = wheelver_num

    elif semver_num:
        requested_version: str = semver.convert_semver_to_wheelver(semver_num)

    else:
        raise ValueError(
            'No version provided. Please provide either semver_num or '
            'wheelver_num.'
        )

    files: list = [file for file in os.listdir(wheel_dir)]

    matches: list = [
        file for file in files
        if extract_version_from_wheel_name(file) == requested_version
    ]

    if matches:
        return wheel_dir + '/' + matches[0]

    elif not matches and raise_not_found:
        raise FileNotFoundError('Could not find wheel file.')

    else:
        return None


class cmd:

    @staticmethod
    @command
    def push_to_gemfury(wheel_file: str, **cmdargs) -> CmdResult:
        return set_result(push_to_gemfury(**strip_args(locals())))

    @staticmethod
    @command
    def push(
        repository='pypi', clean_dir: bool = False, **cmdargs
    ) -> CmdResult:
        return set_result(push(**strip_args(locals())))

    @staticmethod
    @command
    def build(clean_dir: bool = False, **cmdargs) -> CmdResult:
        return set_result(build(**strip_args(locals())))


def push_to_gemfury(wheel_file: str, ) -> None:
    """"""
    sp.run(
        ['fury', 'push', wheel_file],
        check=True,
    )


def _clean_bdist_tmp_files() -> None:
    """"""
    build_dir: str = f'{os.getcwd()}/build'
    egg_file: list = glob.glob('**.egg-info')
    egg_file: str = egg_file and egg_file[0] or ''

    os.path.isdir(build_dir) and shutil.rmtree(build_dir)
    os.path.isdir(egg_file) and shutil.rmtree(egg_file)


def push(
    repository='pypi',
    clean_dir: bool = False,
) -> None:
    """"""
    sp.run(
        ['python', 'setup.py', 'bdist_wheel', 'upload', '-r', repository],
        check=True,
    )

    if clean_dir:
        _clean_bdist_tmp_files()


def build(clean_dir: bool = False, ) -> None:
    """
    @clean_dir: Clean 'build' dir before running build command. This may be necessary because of
    this: https://bitbucket.org/pypa/wheel/issues/147/bdist_wheel-should-start-by-cleaning-up
    """
    sp.run(
        ['python', 'setup.py', 'bdist_wheel'],
        check=True,
    )

    if clean_dir:
        _clean_bdist_tmp_files()

==> buildlib-2.1.13-py3-none-any.whl: buildlib/wheel/lib.py <==
from typing import Optional
import shutil
import os
import glob
from cmdi import CmdResult, command, set_result, strip_args
import subprocess as sp

from .. import semver


def extract_version_from_wheel_name(name: str) -> str:
    """
    Get the version part out of the wheel file name.
    """
    parted: list = name.split('-')
    return '' if len(parted) < 2 else parted[1]


def find_wheel(
    wheel_dir: str,
    semver_num: Optional[str] = None,
    wheelver_num: Optional[str] = None,
    raise_not_found: Optional[bool] = False,
) -> Optional[str]:
    """
    Search dir for a wheel-file which contains a specific version number in its
    name. Return found wheel name or False.

    :param semver_num: Use a semver number to search for the wheel. This will convert the
    semver number into a wheel version number.
    :param wheelver_num: Use the exact version string that you see in the wheel file name to
    search for the wheel.
    """

    if wheelver_num:
        requested_version: str = wheelver_num

    elif semver_num:
        requested_version = semver.convert_semver_to_wheelver(semver_num)

    else:
        raise ValueError(
            'No version provided. Please provide either semver_num or '
            'wheelver_num.'
        )

    files: list = [file for file in os.listdir(wheel_dir)]

    matches: list = [
        file for file in files
        if extract_version_from_wheel_name(file) == requested_version
    ]

    if matches:
        return matches[0]

    elif not matches and raise_not_found:
        raise FileNotFoundError('Could not find wheel file.')

    else:
        return None


def push(
    wheel: str = 'dist/*',
    repository: str = 'pypi',
) -> None:
    """
    Push wheel file to registry via twine.
    """
    sp.run(['twine', 'upload', '-r', repository, wheel], check=True)


def build(cleanup: bool = False) -> None:
    """
    Build wheel.

    :param cleanup: Clean 'build' dir before running build command.
    """
    sp.run(
        ['python', 'setup.py', 'bdist_wheel'],
        check=True,
    )

    if cleanup:
        shutil.rmtree('./build', onerror=None)
        for f in glob.glob('**.egg-info'):
            shutil.rmtree(f)
